@@ -1,7 +1,7 @@
 # /*
 # R-Code for caching
 # S3 atomic 64bit integers for R
-# (c) 2011 Jens Oehlschgel
+# (c) 2011 Jens Oehlschägel
 # Licence: GPL2
 # Provided 'as is', use at your own risk
 # Created: 2011-12-11
@@ -16,7 +16,6 @@
 #! \alias{getcache}
 #! \alias{remcache}
 #! \alias{print.cache}
-#! \alias{still.identical}
 #! \title{
 #! 	Atomic Caching
 #! }
@@ -31,15 +30,11 @@
 #! getcache(x, which)
 #! remcache(x)
 #! \method{print}{cache}(x, all.names = FALSE, pattern, \dots)
-#! still.identical(x, y)
 #! }
 #! \arguments{
 #!   \item{x}{
 #!   an integer64 vector (or a cache object in case of \code{print.cache})
 #! }
-#!   \item{y}{
-#!   an integer64 vector
-#! }
 #!   \item{which}{
 #!   A character naming the object to be retrieved from the cache or to be stored in the cache
 #! }
@@ -60,7 +55,6 @@
 #! 	A \code{cache} is an \code{link{environment}} attached to an atomic object with the \code{link{attrib}} name 'cache'. 
 #! 	It contains at least a reference to the atomic object that carries the cache. 
 #! 	This is used when accessing the cache to detect whether the object carrying the cache has been modified meanwhile.
-#! 	Function \code{still.identical(x,y)} checks whether the objects \code{x} and \code{y} \cr
 #! 	Function \code{newcache(x)} creates a new cache referencing  \code{x} \cr
 #! 	Function \code{jamcache(x)} forces \code{x} to have a cache \cr
 #! 	Function \code{cache(x)} returns the cache attached to \code{x} if it is not found to be outdated \cr
@@ -72,10 +66,11 @@
 #! 	see details
 #! }
 #! \author{
-#! Jens Oehlschlgel <Jens.Oehlschlaegel@truecluster.com>
+#! Jens Oehlschlägel <Jens.Oehlschlaegel@truecluster.com>
 #! }
 #! \seealso{
-#! 	Functions that get and set small cache-content automatically when a cache is present: \code{\link{na.count}}, \code{\link{nvalid}}, \code{\link{is.sorted}}, \code{\link{nunique}} and \code{\link{nties}} \cr
+#!  \code{\link[bit]{still.identical}} for testing whether to symbols point to the same RAM. \cr
+#! 	Functions that get and set small cache-content automatically when a cache is present: \code{\link[bit:Metadata]{na.count}}, \code{\link[bit:Metadata]{nvalid}}, \code{\link[bit:Metadata]{is.sorted}}, \code{\link[bit:Metadata]{nunique}} and \code{\link[bit:Metadata]{nties}} \cr
 #! 	Setting big caches with a relevant memory footprint requires a conscious decision of the user: \code{\link{hashcache}}, \code{\link{sortcache}}, \code{\link{ordercache}} and \code{\link{sortordercache}} \cr
 #! 	Functions that use big caches: \code{\link{match.integer64}}, \code{\link{\%in\%.integer64}}, \code{\link{duplicated.integer64}}, \code{\link{unique.integer64}}, \code{\link{unipos}}, \code{\link{table.integer64}}, \code{\link{as.factor.integer64}}, \code{\link{as.ordered.integer64}}, \code{\link{keypos}}, \code{\link{tiepos}}, \code{\link{rank.integer64}}, \code{\link{prank}}, \code{\link{qtile}}, \code{\link{quantile.integer64}}, \code{\link{median.integer64}} and \code{\link{summary.integer64}} \cr
 #! }
@@ -101,9 +96,9 @@
 #! }
 #! \keyword{ environment }
 
-still.identical <- function(x, y){
-  .Call("r_ram_truly_identical", x = x, y = y, PACKAGE = "bit64")
-}
+#still.identical <- function(x, y){
+#  .Call(C_r_ram_truly_identical, x = x, y = y, PACKAGE = "bit64")
+#}
 
 newcache <- function(x){
 	env <- new.env()
@@ -121,7 +116,7 @@ jamcache <- function(x){
 		cache <- newcache(x)
 		setattr(x, "cache", cache)
 	}else
-		if (!still.identical(x, get("x", envir=cache, inherits=FALSE))){
+		if (!bit::still.identical(x, get("x", envir=cache, inherits=FALSE))){
 			cache <- newcache(x)
 			setattr(x, "cache", cache)
 			warning("replaced outdated cache with empty cache")
@@ -131,7 +126,7 @@ jamcache <- function(x){
 
 cache <- function(x){
 	cache <- attr(x, "cache")
-	if (is.null(cache) || still.identical(x, get("x", envir=cache, inherits=FALSE)))
+	if (is.null(cache) || bit::still.identical(x, get("x", envir=cache, inherits=FALSE)))
 		cache
 	else{ 
 		remcache(x)
@@ -150,7 +145,7 @@ getcache <- function(x, which){
 	cache <- attr(x, "cache")
 	if (is.null(cache))
 	  return(NULL)
-	if (still.identical(x, get("x", envir=cache, inherits=FALSE))){
+	if (bit::still.identical(x, get("x", envir=cache, inherits=FALSE))){
 		if (exists(which, envir=cache, inherits=FALSE))
 			get(which, envir=cache, inherits=FALSE)
 		else
@@ -212,7 +207,7 @@ print.cache<- function(x, all.names=FALSE, pattern, ...){
 #! }
 #! }
 #! \details{
-#! 	The result of relative expensive operations \code{\link{hashmap}}, \code{\link{ramsort}}, \code{\link{ramsortorder}} and \code{\link{ramorder}} can be stored in a cache in order to avoid multiple excutions. Unless in very specific situations, the recommended method is \code{hashsortorder} only.
+#! 	The result of relative expensive operations \code{\link{hashmap}}, \code{\link[=ramsort.integer64]{ramsort}}, \code{\link[=ramsort.integer64]{ramsortorder}} and \code{\link[=ramsort.integer64]{ramorder}} can be stored in a cache in order to avoid multiple excutions. Unless in very specific situations, the recommended method is \code{hashsortorder} only.
 #! }
 #! \note{
 #!   Note that we consider storing the big results from sorting and/or ordering as a relevant side-effect, 
@@ -222,10 +217,10 @@ print.cache<- function(x, all.names=FALSE, pattern, ...){
 #! 	\code{x} with a \code{\link{cache}} that contains the result of the expensive operations, possible together with small derived information (such as \code{\link{nunique.integer64}}) and previously cached results.
 #! }
 #! \author{
-#! Jens Oehlschlgel <Jens.Oehlschlaegel@truecluster.com>
+#! Jens Oehlschlägel <Jens.Oehlschlaegel@truecluster.com>
 #! }
 #! \seealso{
-#! 	\code{\link{cache}} for caching functions and \code{\link{nunique}} for methods bennefitting from small caches
+#! 	\code{\link{cache}} for caching functions and \code{\link{nunique.integer64}} for methods benefiting from small caches
 #! }
 #! \examples{
 #! 	x <- as.integer64(sample(c(rep(NA, 9), 1:9), 32, TRUE))
@@ -255,7 +250,7 @@ sortcache <- function(x, has.na = NULL){
 	}
 	s <- clone(x)
     na.count <- ramsort(s, has.na = has.na, na.last = FALSE, decreasing = FALSE, stable = FALSE, optimize = "time")
-	nut <- .Call("r_ram_integer64_sortnut", x = s, PACKAGE = "bit64")
+	nut <- .Call(C_r_ram_integer64_sortnut, x = s, PACKAGE = "bit64")
     setcache(x, "sort", s)
     setcache(x, "na.count", na.count)
     setcache(x, "nunique", nut[[1]])
@@ -282,7 +277,7 @@ sortordercache <- function(x, has.na = NULL, stable = NULL){
 	s <- clone(x)
 	o <- seq_along(x)
     na.count <- ramsortorder(s, o, has.na = has.na, na.last = FALSE, decreasing = FALSE, stable = stable, optimize = "time")
-	nut <- .Call("r_ram_integer64_sortnut", x = s, PACKAGE = "bit64")
+	nut <- .Call(C_r_ram_integer64_sortnut, x = s, PACKAGE = "bit64")
     setcache(x, "sort", s)
     setcache(x, "order", o)
     setcache(x, "na.count", na.count)
@@ -309,7 +304,7 @@ ordercache <- function(x, has.na = NULL, stable = NULL, optimize = "time"){
 	}
 	o <- seq_along(x)
     na.count <- ramorder(x, o, has.na = has.na, na.last = FALSE, decreasing = FALSE, stable = stable, optimize = optimize)
-	nut <- .Call("r_ram_integer64_ordernut", table = x, order = o, PACKAGE = "bit64")
+	nut <- .Call(C_r_ram_integer64_ordernut, table = x, order = o, PACKAGE = "bit64")
     setcache(x, "order", o)
     setcache(x, "na.count", na.count)
     setcache(x, "nunique", nut[[1]])
@@ -366,7 +361,7 @@ ordercache <- function(x, has.na = NULL, stable = NULL, optimize = "time"){
 #! 	\code{is.sorted} returns a logical scalar, the other methods return an integer scalar.
 #! }
 #! \author{
-#! Jens Oehlschlgel <Jens.Oehlschlaegel@truecluster.com>
+#! Jens Oehlschlägel <Jens.Oehlschlaegel@truecluster.com>
 #! }
 #! \seealso{
 #! 	\code{\link{cache}} for caching functions and \code{\link{sortordercache}} for functions creating big caches
@@ -388,12 +383,12 @@ ordercache <- function(x, has.na = NULL, stable = NULL, optimize = "time"){
 na.count.integer64 <- function(x, ...){
   env <- cache(x)
   if (is.null(env)){
-	.Call("r_ram_integer64_nacount", x = x, PACKAGE = "bit64")
+	.Call(C_r_ram_integer64_nacount, x = x, PACKAGE = "bit64")
   }else{
     if (exists("na.count", envir=env, inherits=FALSE))
 		get("na.count", envir=env, inherits=FALSE)
 	else{
-		ret <- .Call("r_ram_integer64_nacount", x = x, PACKAGE = "bit64")
+		ret <- .Call(C_r_ram_integer64_nacount, x = x, PACKAGE = "bit64")
 		assign("na.count", ret, envir=env)
 		ret
 	}
@@ -407,12 +402,12 @@ nvalid.integer64 <- function(x, ...){
 is.sorted.integer64 <- function(x, ...){
   env <- cache(x)
   if (is.null(env)){
-	.Call("r_ram_integer64_issorted_asc", x = x, PACKAGE = "bit64")
+	.Call(C_r_ram_integer64_issorted_asc, x = x, PACKAGE = "bit64")
   }else{
     if (exists("is.sorted", envir=env, inherits=FALSE))
 		get("is.sorted", envir=env, inherits=FALSE)
 	else{
-		ret <- .Call("r_ram_integer64_issorted_asc", x = x, PACKAGE = "bit64")
+		ret <- .Call(C_r_ram_integer64_issorted_asc, x = x, PACKAGE = "bit64")
 		assign("is.sorted", ret, envir=env)
 		ret
 	}
@@ -431,7 +426,7 @@ nunique.integer64 <- function(x, ...){
 			has.cache <- TRUE
 	}
 	if (is.sorted(x)){
-		ret <- .Call("r_ram_integer64_sortnut"
+		ret <- .Call(C_r_ram_integer64_sortnut
 		, x = x
 		, PACKAGE = "bit64"
 		)
@@ -452,14 +447,14 @@ nties.integer64 <- function(x, ...){
 	cv <- getcache(x, "nties")
 	if (is.null(cv)){
 		if (is.sorted(x)){
-			cv <- .Call("r_ram_integer64_sortnut"
+			cv <- .Call(C_r_ram_integer64_sortnut
 			, x = x
 			, PACKAGE = "bit64"
 			)[2]
 		}else{
 		    s <- clone(x)
 			na.count <- ramsort(s, has.na = TRUE, na.last = FALSE, decreasing = FALSE, stable = FALSE, optimize = "time")
-			cv <- .Call("r_ram_integer64_sortnut", x = s, PACKAGE = "bit64")[[2]]
+			cv <- .Call(C_r_ram_integer64_sortnut, x = s, PACKAGE = "bit64")[[2]]
 		}
 	}
 	cv
